@@ -84,7 +84,7 @@ type SourceState struct {
 	version                 semver.Version
 	mode                    Mode
 	defaultTemplateDataFunc func() map[string]interface{}
-	controlOnly             bool
+	templateDataOnly        bool
 	readTemplateData        bool
 	userTemplateData        map[string]interface{}
 	priorityTemplateData    map[string]interface{}
@@ -112,10 +112,10 @@ func WithCacheDir(cacheDirAbsPath AbsPath) SourceStateOption {
 	}
 }
 
-// WithControlOnly sets whether only control plane information should be read.
-func WithControlOnly(controlOnly bool) SourceStateOption {
+// WithDefaultTemplateDataFunc sets the default template data function.
+func WithDefaultTemplateDataFunc(defaultTemplateDataFunc func() map[string]interface{}) SourceStateOption {
 	return func(s *SourceState) {
-		s.controlOnly = controlOnly
+		s.defaultTemplateDataFunc = defaultTemplateDataFunc
 	}
 }
 
@@ -189,10 +189,10 @@ func WithSystem(system System) SourceStateOption {
 	}
 }
 
-// WithDefaultTemplateDataFunc sets the default template data function.
-func WithDefaultTemplateDataFunc(defaultTemplateDataFunc func() map[string]interface{}) SourceStateOption {
+// WithTemplateDataOnly sets whether only template data should be read.
+func WithTemplateDataOnly(templateDataOnly bool) SourceStateOption {
 	return func(s *SourceState) {
-		s.defaultTemplateDataFunc = defaultTemplateDataFunc
+		s.templateDataOnly = templateDataOnly
 	}
 }
 
@@ -280,6 +280,7 @@ func (s *SourceState) Add(
 	newSourceStateEntries := make(map[SourceRelPath]SourceStateEntry)
 	newSourceStateEntriesByTargetRelPath := make(map[RelPath]SourceStateEntry)
 	nonEmptyDirs := make(map[SourceRelPath]struct{})
+	dirRenames := make(map[AbsPath]AbsPath)
 DESTABSPATH:
 	for _, destAbsPath := range destAbsPaths {
 		destAbsPathInfo := destAbsPathInfos[destAbsPath]
@@ -345,18 +346,19 @@ DESTABSPATH:
 
 				// If both the new and old source state entries are directories
 				// but the name has changed, rename to avoid losing the
-				// directory's contents. Otherwise, remove the old.
+				// directory's contents.
 				_, newIsDir := newSourceStateEntry.(*SourceStateDir)
 				_, oldIsDir := oldSourceStateEntry.(*SourceStateDir)
 				if newIsDir && oldIsDir {
-					newSourceStateEntry = &SourceStateRenameDir{
-						oldSourceRelPath: oldSourceEntryRelPath,
-						newSourceRelPath: sourceEntryRelPath,
-					}
-				} else {
-					newSourceStateEntries[oldSourceEntryRelPath] = &SourceStateRemove{}
-					update.sourceRelPaths = append(update.sourceRelPaths, oldSourceEntryRelPath)
+					oldSourceAbsPath := s.sourceDirAbsPath.Join(oldSourceEntryRelPath.RelPath())
+					newSourceAbsPath := s.sourceDirAbsPath.Join(sourceEntryRelPath.RelPath())
+					dirRenames[oldSourceAbsPath] = newSourceAbsPath
+					continue DESTABSPATH
 				}
+
+				// Otherwise, remove the old entry.
+				newSourceStateEntries[oldSourceEntryRelPath] = &SourceStateRemove{}
+				update.sourceRelPaths = append(update.sourceRelPaths, oldSourceEntryRelPath)
 			}
 		}
 
@@ -453,6 +455,23 @@ DESTABSPATH:
 		}
 	}
 
+	// Rename directories last because updates assume that directory names have
+	// not changed. Rename directories in reverse order so children are renamed
+	// before their parents.
+	oldDirAbsPaths := make([]AbsPath, 0, len(dirRenames))
+	for oldDirAbsPath := range dirRenames {
+		oldDirAbsPaths = append(oldDirAbsPaths, oldDirAbsPath)
+	}
+	sort.Slice(oldDirAbsPaths, func(i, j int) bool {
+		return oldDirAbsPaths[j].Less(oldDirAbsPaths[i])
+	})
+	for _, oldDirAbsPath := range oldDirAbsPaths {
+		newDirAbsPath := dirRenames[oldDirAbsPath]
+		if err := sourceSystem.Rename(oldDirAbsPath, newDirAbsPath); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
@@ -762,6 +781,13 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				return nil
 			}
 			return s.addTemplateData(sourceAbsPath)
+		case fileInfo.Name() == templatesDirName:
+			if err := s.addTemplatesDir(sourceAbsPath); err != nil {
+				return err
+			}
+			return vfs.SkipDir
+		case s.templateDataOnly:
+			return nil
 		case isPrefixDotFormat(fileInfo.Name(), externalName):
 			return s.addExternal(sourceAbsPath)
 		case fileInfo.Name() == ignoreName:
@@ -802,11 +828,6 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				allSourceStateEntries[relPath] = append(allSourceStateEntries[relPath], scriptSourceStateEntries...)
 			}
 			return vfs.SkipDir
-		case fileInfo.Name() == templatesDirName:
-			if err := s.addTemplatesDir(sourceAbsPath); err != nil {
-				return err
-			}
-			return vfs.SkipDir
 		case fileInfo.Name() == VersionName:
 			return s.readVersionFile(sourceAbsPath)
 		case strings.HasPrefix(fileInfo.Name(), Prefix):
@@ -816,8 +837,6 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				return vfs.SkipDir
 			}
 			return nil
-		case s.controlOnly:
-			return nil
 		case fileInfo.IsDir():
 			da := parseDirAttr(sourceName.String())
 			targetRelPath := parentSourceRelPath.Dir().TargetRelPath(s.encryption.EncryptedSuffix()).JoinString(da.TargetName)
@@ -848,7 +867,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 		return err
 	}
 
-	if s.controlOnly {
+	if s.templateDataOnly {
 		return nil
 	}
 
@@ -1095,12 +1114,22 @@ func (s *SourceState) addTemplateData(sourceAbsPath AbsPath) error {
 // addTemplatesDir adds all templates in templatesDirAbsPath to s.
 func (s *SourceState) addTemplatesDir(templatesDirAbsPath AbsPath) error {
 	walkFunc := func(templateAbsPath AbsPath, fileInfo fs.FileInfo, err error) error {
+		if templateAbsPath == templatesDirAbsPath {
+			return nil
+		}
 		if err == nil && fileInfo.Mode().Type() == fs.ModeSymlink {
 			fileInfo, err = s.system.Stat(templateAbsPath)
 		}
 		switch {
 		case err != nil:
 			return err
+		case strings.HasPrefix(fileInfo.Name(), Prefix):
+			return fmt.Errorf("%s: not allowed in %s directory", templatesDirName, templateAbsPath)
+		case strings.HasPrefix(fileInfo.Name(), "."):
+			if fileInfo.IsDir() {
+				return vfs.SkipDir
+			}
+			return nil
 		case fileInfo.Mode().IsRegular():
 			contents, err := s.system.ReadFile(templateAbsPath)
 			if err != nil {
@@ -1852,7 +1881,7 @@ func (s *SourceState) readScriptsDir(scriptsDirAbsPath AbsPath) (map[RelPath][]S
 		case err != nil:
 			return err
 		case strings.HasPrefix(fileInfo.Name(), Prefix):
-			return fmt.Errorf("%s: not allowed in .chezmoiscripts directory", sourceAbsPath)
+			return fmt.Errorf("%s: not allowed in %s directory", sourceAbsPath, scriptsDirName)
 		case strings.HasPrefix(fileInfo.Name(), ignorePrefix):
 			if fileInfo.IsDir() {
 				return vfs.SkipDir
