@@ -24,11 +24,12 @@ type archiveCmdConfig struct {
 
 func (c *Config) newArchiveCmd() *cobra.Command {
 	archiveCmd := &cobra.Command{
-		Use:     "archive [target]...",
-		Short:   "Generate a tar archive of the target state",
-		Long:    mustLongHelp("archive"),
-		Example: example("archive"),
-		RunE:    c.runArchiveCmd,
+		Use:               "archive [target]...",
+		Short:             "Generate a tar archive of the target state",
+		Long:              mustLongHelp("archive"),
+		Example:           example("archive"),
+		ValidArgsFunction: c.targetValidArgs,
+		RunE:              c.runArchiveCmd,
 		Annotations: map[string]string{
 			persistentStateMode: persistentStateModeEmpty,
 		},
@@ -66,7 +67,7 @@ func (c *Config) runArchiveCmd(cmd *cobra.Command, args []string) error {
 	}
 	switch format {
 	case chezmoi.ArchiveFormatTar, chezmoi.ArchiveFormatTarGz, chezmoi.ArchiveFormatTgz:
-		archiveSystem = chezmoi.NewTARWriterSystem(&output, tarHeaderTemplate())
+		archiveSystem = chezmoi.NewTarWriterSystem(&output, tarHeaderTemplate())
 	case chezmoi.ArchiveFormatZip:
 		archiveSystem = chezmoi.NewZIPWriterSystem(&output, time.Now().UTC())
 	default:
