@@ -20,9 +20,7 @@ var (
 		regexp.MustCompile(`\A\.idea\z`),
 		regexp.MustCompile(`\A\.vagrant\z`),
 		regexp.MustCompile(`\A\.vscode/settings\.json\z`),
-		regexp.MustCompile(`\Aassets/chezmoi\.io/public\z`),
-		regexp.MustCompile(`\Aassets/chezmoi\.io/resources\z`),
-		regexp.MustCompile(`\Aassets/chezmoi\.io/themes/book\z`),
+		regexp.MustCompile(`\Aassets/chezmoi\.io/site\z`),
 		regexp.MustCompile(`\Aassets/scripts/install\.ps1\z`),
 		regexp.MustCompile(`\Acompletions/chezmoi\.ps1\z`),
 		regexp.MustCompile(`\Adist\z`),
